--------------------------------------------------------------------------------------------------------------
--
-- Module     : SIMS Database SQL Server 2005
-- Platform   : SIMS
-- Area       : DBUpgrade Database Patch
-- Copyright  : (c) Capita Education Services 2005-2009
--            : This code has been written by Capita Education Services for use within its own SIMS systems.
--            : It is unpublished proprietary work, and as such it is illegal for it to be reproduced by any
--            : means or used without the express written permission of Capita Education Services.
-- Patch ID   : 17755
--
--------------------------------------------------------------------------------------------------------------

-- Check this is within the acceptible range
  IF NOT EXISTS(
	SELECT 1 
	FROM	sims.db_version_info
	WHERE	schema_version BETWEEN '3.61.834' AND '3.61.999')
  BEGIN
    DECLARE @error_msg2 VARCHAR(100)
    SET @error_msg2 = CHAR(10) + CHAR(13) + 'This patch is not applicable to this database version.' + CHAR(10) + CHAR(13)
	raiserror(@error_msg2, 18, 1)
  END

-- This is a RunOnce patch - check its not already been applied.
ELSE IF EXISTS(SELECT 1 
	        FROM   sims.db_update_log 
	        WHERE	patch_id = 17755)
  BEGIN
    DECLARE @error_msg1 VARCHAR(100)
    SET @error_msg1 = CHAR(10) + CHAR(13) + 'This patch has already been run on the database and cannot be run again.' + CHAR(10) + CHAR(13)
	raiserror(@error_msg1, 18, 1) 
  END

GO
-- START PATCH CODE



-- START PATCH SCRIPT 1

-- Extend SchoolComms license for Focus Plugin (external id from patch 16918)

Declare @external_Id as UNIQUEIDENTIFIER
SELECT @external_id = '7B67024F-85CD-4844-989A-3E33BBE90A58'

update sims.tpi_plugin 
   set licence_end_date = '2020-12-31 23:59:00'
where external_id = @external_id   





-- END PATCH SCRIPT 1
GO


-- START PATCH SCRIPT 2

-- Extend SchoolComms license for Student Plugin (external id from patch 16918)

Declare @external_Id as UNIQUEIDENTIFIER
SELECT @external_id = '584D2F89-6982-4B3F-92EA-8A6FE1C05511'

update sims.tpi_plugin 
   set licence_end_date = '2020-12-31 23:59:00'
where external_id = @external_id   


-- END PATCH SCRIPT 2
GO


-- END PATCH CODE



-- Record that this patch has been updated
INSERT INTO sims.db_update_log
(
	patch_id,
	update_id,
	successful,
	description,
	update_type,
	date_applied
)
VALUES
(
	17755,
	1,
	'T',
	'Patch updates the licence for Student and Focus menus',
	'U',
	GetDate()
)

